numina.visualization — Data visualization — Numina 0.20.dev0 documentation

# `numina.visualization` — Data visualization

Visualization utilities.

class `numina.visualization.` `ZScaleInterval`(contrast=0.25)

  Compute z1 and z2 cuts in a similar way to Iraf.

  If the total number of pixels is less than 10, the function simply returns the minimum and the maximum values.

  Parameters: | contrast (float, optional) – The scaling factor (between 0 and 1) for determining the minimum and maximum value. Larger values increase the difference between the minimum and maximum values used for display. Defaults to 0.25.

  :param .. note:: Deprecated in numina 0.10: Use astropy.visualization.ZScaleInterval instead.
    It will be removed in numina 1.0
  `get_limits`(values)

    Return the minimum and maximum value in the interval based on the values provided.

    Parameters: | values (~numpy.ndarray) – The image values.
    Returns: | vmin, vmax – The mininium and maximum image value in the interval.
    Return type: | float